==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/V1beta1CSIDriverSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1beta1CSIDriverSpecFluent<A extends V1beta1CSIDriverSpecFluent<A>> extends Fluent<A>{


    public Boolean isAttachRequired();
    public A withAttachRequired(Boolean attachRequired);
    public Boolean hasAttachRequired();
    public A withNewAttachRequired(String arg1);
    public A withNewAttachRequired(boolean arg1);
    public Boolean isPodInfoOnMount();
    public A withPodInfoOnMount(Boolean podInfoOnMount);
    public Boolean hasPodInfoOnMount();
    public A withNewPodInfoOnMount(String arg1);
    public A withNewPodInfoOnMount(boolean arg1);
    public A addToVolumeLifecycleModes(int index,String item);
    public A setToVolumeLifecycleModes(int index,String item);
    public A addToVolumeLifecycleModes(String... items);
    public A addAllToVolumeLifecycleModes(Collection<String> items);
    public A removeFromVolumeLifecycleModes(String... items);
    public A removeAllFromVolumeLifecycleModes(Collection<String> items);
    public List<String> getVolumeLifecycleModes();
    public String getVolumeLifecycleMode(int index);
    public String getFirstVolumeLifecycleMode();
    public String getLastVolumeLifecycleMode();
    public String getMatchingVolumeLifecycleMode(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingVolumeLifecycleMode(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withVolumeLifecycleModes(List<String> volumeLifecycleModes);
    public A withVolumeLifecycleModes(String... volumeLifecycleModes);
    public Boolean hasVolumeLifecycleModes();
    public A addNewVolumeLifecycleMode(String arg1);
    public A addNewVolumeLifecycleMode(StringBuilder arg1);
    public A addNewVolumeLifecycleMode(StringBuffer arg1);



}

==> client-java-api-11.0.4-sources.jar: io/kubernetes/client/openapi/models/V1beta1CSIDriverSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1beta1CSIDriverSpecFluent<A extends V1beta1CSIDriverSpecFluent<A>> extends Fluent<A> {


    public Boolean isAttachRequired();
    public A withAttachRequired(Boolean attachRequired);
    public Boolean hasAttachRequired();
    public A withNewAttachRequired(String arg1);
    public A withNewAttachRequired(boolean arg1);
    public String getFsGroupPolicy();
    public A withFsGroupPolicy(String fsGroupPolicy);
    public Boolean hasFsGroupPolicy();
    public A withNewFsGroupPolicy(String arg1);
    public A withNewFsGroupPolicy(StringBuilder arg1);
    public A withNewFsGroupPolicy(StringBuffer arg1);
    public Boolean isPodInfoOnMount();
    public A withPodInfoOnMount(Boolean podInfoOnMount);
    public Boolean hasPodInfoOnMount();
    public A withNewPodInfoOnMount(String arg1);
    public A withNewPodInfoOnMount(boolean arg1);
    public Boolean isStorageCapacity();
    public A withStorageCapacity(Boolean storageCapacity);
    public Boolean hasStorageCapacity();
    public A withNewStorageCapacity(String arg1);
    public A withNewStorageCapacity(boolean arg1);
    public A addToVolumeLifecycleModes(int index,String item);
    public A setToVolumeLifecycleModes(int index,String item);
    public A addToVolumeLifecycleModes(String... items);
    public A addAllToVolumeLifecycleModes(Collection<String> items);
    public A removeFromVolumeLifecycleModes(String... items);
    public A removeAllFromVolumeLifecycleModes(Collection<String> items);
    public List<String> getVolumeLifecycleModes();
    public String getVolumeLifecycleMode(int index);
    public String getFirstVolumeLifecycleMode();
    public String getLastVolumeLifecycleMode();
    public String getMatchingVolumeLifecycleMode(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingVolumeLifecycleMode(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withVolumeLifecycleModes(List<String> volumeLifecycleModes);
    public A withVolumeLifecycleModes(String... volumeLifecycleModes);
    public Boolean hasVolumeLifecycleModes();
    public A addNewVolumeLifecycleMode(String arg1);
    public A addNewVolumeLifecycleMode(StringBuilder arg1);
    public A addNewVolumeLifecycleMode(StringBuffer arg1);
}
